@@ -13,11 +13,11 @@ from wavefront_api_client.api.derived_metric_api import DerivedMetricApi
 from wavefront_api_client.api.direct_ingestion_api import DirectIngestionApi
 from wavefront_api_client.api.event_api import EventApi
 from wavefront_api_client.api.external_link_api import ExternalLinkApi
+from wavefront_api_client.api.ingestion_spy_api import IngestionSpyApi
 from wavefront_api_client.api.integration_api import IntegrationApi
 from wavefront_api_client.api.maintenance_window_api import MaintenanceWindowApi
 from wavefront_api_client.api.message_api import MessageApi
 from wavefront_api_client.api.metric_api import MetricApi
-from wavefront_api_client.api.monitored_cluster_api import MonitoredClusterApi
 from wavefront_api_client.api.notificant_api import NotificantApi
 from wavefront_api_client.api.proxy_api import ProxyApi
 from wavefront_api_client.api.query_api import QueryApi
